@@ -2,6 +2,8 @@
 #' @param comparisonColors Colors to use for the two groups in a
 #' binary CIBER plot with one (dichotomous) target.
 #' @param categoryLabels Labels for the two values of the target.
+#' @param dotAlpha The alpha (opaqueness, i.e. inverse transparency) of the
+#' dots representing data points.
 #' @examples \donttest{### With a binary target
 #' data(BBC_pp17.1);
 #' behaviorchange::binaryCIBER(data=BBC_pp17.1,
@@ -45,6 +47,7 @@ binaryCIBER <- function(data,
                         titleSuffix = "",
                         fullColorRange = NULL,
                         associationsAlpha = .5,
+                        dotAlpha = .33,
                         returnPlotOnly = TRUE,
                         drawPlot = TRUE,
                         baseSize = .8,
@@ -162,11 +165,23 @@ binaryCIBER <- function(data,
                                         decreasing=res$intermediate$decreasing);
   } else if (orderBy %IN% (targets)) {
     tryCatch({
+
+      assocMatrix <-
+        ufs::associationMatrix(data,
+                               x=determinants,
+                               y=orderBy);
+
+      dataToSort <-
+        assocMatrix$output$raw$es[,1];
+
+      # sortedAssocMatrix <-
+      #   sort(dataToSort,
+      #        decreasing=res$intermediate$decreasing);
+
       res$intermediate$sortOrder <-
-        sort(ufs::associationMatrix(data,
-                                    x=determinants,
-                                    y=orderBy),
-             decreasing=res$intermediate$decreasing)$intermediate$sorting$order;
+        order(dataToSort);
+        #sortedAssocMatrix$intermediate$sorting$order;
+
     }, error = function(errorMsg) {
       stop("When trying to call associationMatrix to get the sorting order, ",
            "the data frame no longer has class 'numeric', but instead '",
@@ -284,6 +299,7 @@ binaryCIBER <- function(data,
                              fullColorRange = res$intermediate$fullColorRange,
                              conf.level = conf.level$means,
                              drawPlot = FALSE,
+                             dataAlpha = dotAlpha,
                              returnPlotOnly = FALSE,
                              dotSize = dotSize,
                              baseFontSize = baseFontSize,
@@ -301,6 +317,7 @@ binaryCIBER <- function(data,
                              fullColorRange = res$intermediate$fullColorRange,
                              conf.level = conf.level$means,
                              drawPlot = FALSE,
+                             dataAlpha = dotAlpha,
                              returnPlotOnly = FALSE,
                              dotSize = dotSize,
                              baseFontSize = baseFontSize,
@@ -328,6 +345,7 @@ binaryCIBER <- function(data,
                                       compareBy=targets,
                                       labels = labels,
                                       xbreaks = xbreaks,
+                                      dataAlpha = dotAlpha,
                                       conf.level=conf.level$means,
                                       comparisonColors=comparisonColors,
                                       legend.position="left",
