@@ -26,15 +26,23 @@ detStructCIBER <- function(determinantStructure,
                            theme=ggplot2::theme_bw(base_size=baseFontSize),
                            ...) {
 
-  determinantStructure$Do(function(currentNode) {
+  data.tree::Do(nodes=data.tree::Traverse(determinantStructure,
+                                          traversal = 'level', filterFun = function(x)
+                                            return((x$type=="subdeterminants") ||
+                                                     (x$type=="subdeterminantProducts"))),
+                fun=function(currentNode) {
 
-    varNames <- currentNode$Get('name', traversal='ancestor',
-                                filterFun=function(x)
-                                  return(x$type=='determinantVar'));
+    varNames <- data.tree::Get(nodes=data.tree::Traverse(currentNode,
+                                                         traversal='ancestor',
+                                                         filterFun=function(x)
+                                                           return(x$type=='determinantVar')),
+                               attribute='name');
 
-    scaleVarNames <- currentNode$Get('scaleVarName', traversal='ancestor',
-                                     filterFun=function(x)
-                                       return(x$type=='determinantVar'));
+    scaleVarNames <- data.tree::Get(data.tree::Traverse(currentNode,
+                                                        traversal='ancestor',
+                                                        filterFun=function(x)
+                                                          return(x$type=='determinantVar')),
+                                    attribute='scaleVarName');
 
     targets <-
       ufs::ifelseObj(is.null(scaleVarNames),
@@ -86,9 +94,6 @@ detStructCIBER <- function(determinantStructure,
                             baseFontSize=baseFontSize,
                             theme=theme,
                             ...);
-  }, traversal = 'level', filterFun = function(x)
-    return((x$type=="subdeterminants") ||
-           (x$type=="subdeterminantProducts"))
-  );
+  });
 
 }
\ No newline at end of file
