@@ -164,7 +164,19 @@ opts$defaults <-
                                      c("\\\\", "/"),
                                      c("[^a-zA-Z0-9;)(,._/`-]", " ")),
 
+       ### From the {see} package:
+       ### https://easystats.github.io/see/reference/okabeito_colors.html
+       ### Specifically, dput(see::okabeito_colors());
 
+       palette_okabe_ito =
+         c(orange = "#E69F00", `light blue` = "#56B4E9", green = "#009E73",
+           amber = "#F5C710", blue = "#0072B2", red = "#D55E00", purple = "#CC79A7",
+           grey = "#999999", black = "#000000"),
+
+       palette_okabe_ito_reorganized =
+         c(blue = "#0072B2", orange = "#E69F00", purple = "#CC79A7",
+           green = "#009E73", red = "#D55E00", `light blue` = "#56B4E9",
+           amber = "#F5C710", grey = "#999999", black = "#000000"),
 
        ### Where to print tables; 'console', 'viewer', and/or
        ### one or more filenames in existing directories
